package com.hrsk.cloud.eg.domain.api.resolver.vo;

import com.hrsk.cloud.eg.domain.api.ApiContext;
import com.hrsk.cloud.eg.domain.api.ApiResult;
import com.hrsk.cloud.eg.domain.api.ValueObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.expression.ExpressionParser;
import org.springframework.expression.spel.standard.SpelExpressionParser;

/**
 * @author: bianlanzhou
 * @create: 2024-07-31 14:38
 * @description: Spel值对象解析器
 **/
@Slf4j
public class SpelValueObjectResolver  implements ValueObjectResolver{
    /**
     * spel parser
     */
    private final ExpressionParser parser = new SpelExpressionParser();

    /**
     * 解析
     * @param valueObject 解析对象
     * @param context 上下文
     * @return 解析结果
     */
    @Override
    public Object resolve(ValueObject valueObject, ApiContext context) {
        try{
            return parser.parseExpression(valueObject.getValue()).getValue(context.getSpelContext());
        }catch (Exception ex){
            log.error("属性配置错误!",ex);
            return null;
        }
    }

    /**
     * 解析
     * @param valueObject 解析对象
     * @param context 返回值
     * @return 解析结果
     */
    @Override
    public Object resolve(ValueObject valueObject, ApiResult context) {
        try{
            return parser.parseExpression(valueObject.getValue()).getValue(context.getSpelContext());
        }catch (Exception ex){
            log.error("属性配置错误!",ex);
            return null;
        }
    }
}
